from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Microsoft.UI
import win32more.Microsoft.UI.Dispatching
import win32more.Microsoft.UI.Windowing
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics
import win32more.Windows.UI
import win32more.Windows.Win32.System.WinRT
class AppWindow(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Windowing.IAppWindow
    _classid_ = 'Microsoft.UI.Windowing.AppWindow'
    @winrt_mixinmethod
    def ShowWithActivation(self: win32more.Microsoft.UI.Windowing.IAppWindow, activateWindow: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsShownInSwitchers(self: win32more.Microsoft.UI.Windowing.IAppWindow) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsShownInSwitchers(self: win32more.Microsoft.UI.Windowing.IAppWindow, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsVisible(self: win32more.Microsoft.UI.Windowing.IAppWindow) -> Boolean: ...
    @winrt_mixinmethod
    def get_OwnerWindowId(self: win32more.Microsoft.UI.Windowing.IAppWindow) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_mixinmethod
    def get_Position(self: win32more.Microsoft.UI.Windowing.IAppWindow) -> win32more.Windows.Graphics.PointInt32: ...
    @winrt_mixinmethod
    def get_Presenter(self: win32more.Microsoft.UI.Windowing.IAppWindow) -> win32more.Microsoft.UI.Windowing.AppWindowPresenter: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Microsoft.UI.Windowing.IAppWindow) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Microsoft.UI.Windowing.IAppWindow) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Microsoft.UI.Windowing.IAppWindow, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_TitleBar(self: win32more.Microsoft.UI.Windowing.IAppWindow) -> win32more.Microsoft.UI.Windowing.AppWindowTitleBar: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Microsoft.UI.Windowing.IAppWindow) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_mixinmethod
    def Hide(self: win32more.Microsoft.UI.Windowing.IAppWindow) -> Void: ...
    @winrt_mixinmethod
    def Move(self: win32more.Microsoft.UI.Windowing.IAppWindow, position: win32more.Windows.Graphics.PointInt32) -> Void: ...
    @winrt_mixinmethod
    def MoveAndResize(self: win32more.Microsoft.UI.Windowing.IAppWindow, rect: win32more.Windows.Graphics.RectInt32) -> Void: ...
    @winrt_mixinmethod
    def MoveAndResizeRelativeToDisplayArea(self: win32more.Microsoft.UI.Windowing.IAppWindow, rect: win32more.Windows.Graphics.RectInt32, displayarea: win32more.Microsoft.UI.Windowing.DisplayArea) -> Void: ...
    @winrt_mixinmethod
    def Resize(self: win32more.Microsoft.UI.Windowing.IAppWindow, size: win32more.Windows.Graphics.SizeInt32) -> Void: ...
    @winrt_mixinmethod
    def SetIcon(self: win32more.Microsoft.UI.Windowing.IAppWindow, iconPath: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def SetIconWithIconId(self: win32more.Microsoft.UI.Windowing.IAppWindow, iconId: win32more.Microsoft.UI.IconId) -> Void: ...
    @winrt_mixinmethod
    def SetPresenter(self: win32more.Microsoft.UI.Windowing.IAppWindow, appWindowPresenter: win32more.Microsoft.UI.Windowing.AppWindowPresenter) -> Void: ...
    @winrt_mixinmethod
    def SetPresenterByKind(self: win32more.Microsoft.UI.Windowing.IAppWindow, appWindowPresenterKind: win32more.Microsoft.UI.Windowing.AppWindowPresenterKind) -> Void: ...
    @winrt_mixinmethod
    def Show(self: win32more.Microsoft.UI.Windowing.IAppWindow) -> Void: ...
    @winrt_mixinmethod
    def Destroy(self: win32more.Microsoft.UI.Windowing.IAppWindow) -> Void: ...
    @winrt_mixinmethod
    def add_Changed(self: win32more.Microsoft.UI.Windowing.IAppWindow, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.AppWindow, win32more.Microsoft.UI.Windowing.AppWindowChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Changed(self: win32more.Microsoft.UI.Windowing.IAppWindow, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closing(self: win32more.Microsoft.UI.Windowing.IAppWindow, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.AppWindow, win32more.Microsoft.UI.Windowing.AppWindowClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closing(self: win32more.Microsoft.UI.Windowing.IAppWindow, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Destroying(self: win32more.Microsoft.UI.Windowing.IAppWindow, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.AppWindow, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Destroying(self: win32more.Microsoft.UI.Windowing.IAppWindow, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_ClientSize(self: win32more.Microsoft.UI.Windowing.IAppWindow2) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_mixinmethod
    def MoveInZOrderAtBottom(self: win32more.Microsoft.UI.Windowing.IAppWindow2) -> Void: ...
    @winrt_mixinmethod
    def MoveInZOrderAtTop(self: win32more.Microsoft.UI.Windowing.IAppWindow2) -> Void: ...
    @winrt_mixinmethod
    def MoveInZOrderBelow(self: win32more.Microsoft.UI.Windowing.IAppWindow2, windowId: win32more.Microsoft.UI.WindowId) -> Void: ...
    @winrt_mixinmethod
    def ResizeClient(self: win32more.Microsoft.UI.Windowing.IAppWindow2, size: win32more.Windows.Graphics.SizeInt32) -> Void: ...
    @winrt_mixinmethod
    def ShowOnceWithRequestedStartupState(self: win32more.Microsoft.UI.Windowing.IAppWindow2) -> Void: ...
    @winrt_mixinmethod
    def AssociateWithDispatcherQueue(self: win32more.Microsoft.UI.Windowing.IAppWindow3, dispatcherQueue: win32more.Microsoft.UI.Dispatching.DispatcherQueue) -> Void: ...
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Microsoft.UI.Windowing.IAppWindow3) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    @winrt_classmethod
    def CreateWithDispatcherQueue(cls: win32more.Microsoft.UI.Windowing.IAppWindowStatics2, appWindowPresenter: win32more.Microsoft.UI.Windowing.AppWindowPresenter, ownerWindowId: win32more.Microsoft.UI.WindowId, DispatcherQueue: win32more.Microsoft.UI.Dispatching.DispatcherQueue) -> win32more.Microsoft.UI.Windowing.AppWindow: ...
    @winrt_classmethod
    def Create(cls: win32more.Microsoft.UI.Windowing.IAppWindowStatics) -> win32more.Microsoft.UI.Windowing.AppWindow: ...
    @winrt_classmethod
    def CreateWithPresenter(cls: win32more.Microsoft.UI.Windowing.IAppWindowStatics, appWindowPresenter: win32more.Microsoft.UI.Windowing.AppWindowPresenter) -> win32more.Microsoft.UI.Windowing.AppWindow: ...
    @winrt_classmethod
    def CreateWithPresenterAndOwner(cls: win32more.Microsoft.UI.Windowing.IAppWindowStatics, appWindowPresenter: win32more.Microsoft.UI.Windowing.AppWindowPresenter, ownerWindowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.Windowing.AppWindow: ...
    @winrt_classmethod
    def GetFromWindowId(cls: win32more.Microsoft.UI.Windowing.IAppWindowStatics, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.Windowing.AppWindow: ...
    ClientSize = property(get_ClientSize, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    Id = property(get_Id, None)
    IsShownInSwitchers = property(get_IsShownInSwitchers, put_IsShownInSwitchers)
    IsVisible = property(get_IsVisible, None)
    OwnerWindowId = property(get_OwnerWindowId, None)
    Position = property(get_Position, None)
    Presenter = property(get_Presenter, None)
    Size = property(get_Size, None)
    Title = property(get_Title, put_Title)
    TitleBar = property(get_TitleBar, None)
    Changed = event()
    Closing = event()
    Destroying = event()
class AppWindowChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Windowing.IAppWindowChangedEventArgs
    _classid_ = 'Microsoft.UI.Windowing.AppWindowChangedEventArgs'
    @winrt_mixinmethod
    def get_DidPositionChange(self: win32more.Microsoft.UI.Windowing.IAppWindowChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidPresenterChange(self: win32more.Microsoft.UI.Windowing.IAppWindowChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidSizeChange(self: win32more.Microsoft.UI.Windowing.IAppWindowChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidVisibilityChange(self: win32more.Microsoft.UI.Windowing.IAppWindowChangedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_DidZOrderChange(self: win32more.Microsoft.UI.Windowing.IAppWindowChangedEventArgs2) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsZOrderAtBottom(self: win32more.Microsoft.UI.Windowing.IAppWindowChangedEventArgs2) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsZOrderAtTop(self: win32more.Microsoft.UI.Windowing.IAppWindowChangedEventArgs2) -> Boolean: ...
    @winrt_mixinmethod
    def get_ZOrderBelowWindowId(self: win32more.Microsoft.UI.Windowing.IAppWindowChangedEventArgs2) -> win32more.Microsoft.UI.WindowId: ...
    DidPositionChange = property(get_DidPositionChange, None)
    DidPresenterChange = property(get_DidPresenterChange, None)
    DidSizeChange = property(get_DidSizeChange, None)
    DidVisibilityChange = property(get_DidVisibilityChange, None)
    DidZOrderChange = property(get_DidZOrderChange, None)
    IsZOrderAtBottom = property(get_IsZOrderAtBottom, None)
    IsZOrderAtTop = property(get_IsZOrderAtTop, None)
    ZOrderBelowWindowId = property(get_ZOrderBelowWindowId, None)
class AppWindowClosingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Windowing.IAppWindowClosingEventArgs
    _classid_ = 'Microsoft.UI.Windowing.AppWindowClosingEventArgs'
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Windowing.IAppWindowClosingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Windowing.IAppWindowClosingEventArgs, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
class AppWindowPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Windowing.IAppWindowPresenter
    _classid_ = 'Microsoft.UI.Windowing.AppWindowPresenter'
    @winrt_mixinmethod
    def get_Kind(self: win32more.Microsoft.UI.Windowing.IAppWindowPresenter) -> win32more.Microsoft.UI.Windowing.AppWindowPresenterKind: ...
    Kind = property(get_Kind, None)
class AppWindowPresenterKind(Enum, Int32):
    Default = 0
    CompactOverlay = 1
    FullScreen = 2
    Overlapped = 3
class AppWindowTitleBar(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar
    _classid_ = 'Microsoft.UI.Windowing.AppWindowTitleBar'
    @winrt_mixinmethod
    def get_ButtonInactiveForegroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_BackgroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_ButtonBackgroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_ButtonBackgroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_ButtonForegroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_ButtonForegroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_ButtonHoverBackgroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_ButtonHoverBackgroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_ButtonHoverForegroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_ButtonHoverForegroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_ButtonInactiveBackgroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_ButtonInactiveBackgroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_ButtonPressedBackgroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_ButtonInactiveForegroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_BackgroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_ButtonPressedBackgroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_ButtonPressedForegroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_ButtonPressedForegroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_ExtendsContentIntoTitleBar(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> Boolean: ...
    @winrt_mixinmethod
    def put_ExtendsContentIntoTitleBar(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ForegroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_ForegroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_Height(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> Int32: ...
    @winrt_mixinmethod
    def get_IconShowOptions(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> win32more.Microsoft.UI.Windowing.IconShowOptions: ...
    @winrt_mixinmethod
    def put_IconShowOptions(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: win32more.Microsoft.UI.Windowing.IconShowOptions) -> Void: ...
    @winrt_mixinmethod
    def get_InactiveBackgroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_InactiveBackgroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_InactiveForegroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_mixinmethod
    def put_InactiveForegroundColor(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_mixinmethod
    def get_LeftInset(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> Int32: ...
    @winrt_mixinmethod
    def get_RightInset(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> Int32: ...
    @winrt_mixinmethod
    def ResetToDefault(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar) -> Void: ...
    @winrt_mixinmethod
    def SetDragRectangles(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar, value: PassArray[win32more.Windows.Graphics.RectInt32]) -> Void: ...
    @winrt_mixinmethod
    def get_PreferredHeightOption(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar2) -> win32more.Microsoft.UI.Windowing.TitleBarHeightOption: ...
    @winrt_mixinmethod
    def put_PreferredHeightOption(self: win32more.Microsoft.UI.Windowing.IAppWindowTitleBar2, value: win32more.Microsoft.UI.Windowing.TitleBarHeightOption) -> Void: ...
    @winrt_classmethod
    def IsCustomizationSupported(cls: win32more.Microsoft.UI.Windowing.IAppWindowTitleBarStatics) -> Boolean: ...
    BackgroundColor = property(get_BackgroundColor, put_BackgroundColor)
    ButtonBackgroundColor = property(get_ButtonBackgroundColor, put_ButtonBackgroundColor)
    ButtonForegroundColor = property(get_ButtonForegroundColor, put_ButtonForegroundColor)
    ButtonHoverBackgroundColor = property(get_ButtonHoverBackgroundColor, put_ButtonHoverBackgroundColor)
    ButtonHoverForegroundColor = property(get_ButtonHoverForegroundColor, put_ButtonHoverForegroundColor)
    ButtonInactiveBackgroundColor = property(get_ButtonInactiveBackgroundColor, put_ButtonInactiveBackgroundColor)
    ButtonInactiveForegroundColor = property(get_ButtonInactiveForegroundColor, put_ButtonInactiveForegroundColor)
    ButtonPressedBackgroundColor = property(get_ButtonPressedBackgroundColor, put_ButtonPressedBackgroundColor)
    ButtonPressedForegroundColor = property(get_ButtonPressedForegroundColor, put_ButtonPressedForegroundColor)
    ExtendsContentIntoTitleBar = property(get_ExtendsContentIntoTitleBar, put_ExtendsContentIntoTitleBar)
    ForegroundColor = property(get_ForegroundColor, put_ForegroundColor)
    Height = property(get_Height, None)
    IconShowOptions = property(get_IconShowOptions, put_IconShowOptions)
    InactiveBackgroundColor = property(get_InactiveBackgroundColor, put_InactiveBackgroundColor)
    InactiveForegroundColor = property(get_InactiveForegroundColor, put_InactiveForegroundColor)
    LeftInset = property(get_LeftInset, None)
    PreferredHeightOption = property(get_PreferredHeightOption, put_PreferredHeightOption)
    RightInset = property(get_RightInset, None)
class CompactOverlayPresenter(ComPtr):
    extends: win32more.Microsoft.UI.Windowing.AppWindowPresenter
    default_interface: win32more.Microsoft.UI.Windowing.ICompactOverlayPresenter
    _classid_ = 'Microsoft.UI.Windowing.CompactOverlayPresenter'
    @winrt_mixinmethod
    def put_InitialSize(self: win32more.Microsoft.UI.Windowing.ICompactOverlayPresenter, value: win32more.Microsoft.UI.Windowing.CompactOverlaySize) -> Void: ...
    @winrt_mixinmethod
    def get_InitialSize(self: win32more.Microsoft.UI.Windowing.ICompactOverlayPresenter) -> win32more.Microsoft.UI.Windowing.CompactOverlaySize: ...
    @winrt_classmethod
    def Create(cls: win32more.Microsoft.UI.Windowing.ICompactOverlayPresenterStatics) -> win32more.Microsoft.UI.Windowing.CompactOverlayPresenter: ...
    InitialSize = property(get_InitialSize, put_InitialSize)
class CompactOverlaySize(Enum, Int32):
    Small = 0
    Medium = 1
    Large = 2
class _DisplayArea_Meta_(ComPtr.__class__):
    pass
class DisplayArea(ComPtr, metaclass=_DisplayArea_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Windowing.IDisplayArea
    _classid_ = 'Microsoft.UI.Windowing.DisplayArea'
    @winrt_mixinmethod
    def get_IsPrimary(self: win32more.Microsoft.UI.Windowing.IDisplayArea) -> Boolean: ...
    @winrt_mixinmethod
    def get_DisplayId(self: win32more.Microsoft.UI.Windowing.IDisplayArea) -> win32more.Microsoft.UI.DisplayId: ...
    @winrt_mixinmethod
    def get_OuterBounds(self: win32more.Microsoft.UI.Windowing.IDisplayArea) -> win32more.Windows.Graphics.RectInt32: ...
    @winrt_mixinmethod
    def get_WorkArea(self: win32more.Microsoft.UI.Windowing.IDisplayArea) -> win32more.Windows.Graphics.RectInt32: ...
    @winrt_classmethod
    def GetFromDisplayId(cls: win32more.Microsoft.UI.Windowing.IDisplayAreaStatics2, displayId: win32more.Microsoft.UI.DisplayId) -> win32more.Microsoft.UI.Windowing.DisplayArea: ...
    @winrt_classmethod
    def get_Primary(cls: win32more.Microsoft.UI.Windowing.IDisplayAreaStatics) -> win32more.Microsoft.UI.Windowing.DisplayArea: ...
    @winrt_classmethod
    def CreateWatcher(cls: win32more.Microsoft.UI.Windowing.IDisplayAreaStatics) -> win32more.Microsoft.UI.Windowing.DisplayAreaWatcher: ...
    @winrt_classmethod
    def FindAll(cls: win32more.Microsoft.UI.Windowing.IDisplayAreaStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Windowing.DisplayArea]: ...
    @winrt_classmethod
    def GetFromWindowId(cls: win32more.Microsoft.UI.Windowing.IDisplayAreaStatics, windowId: win32more.Microsoft.UI.WindowId, displayAreaFallback: win32more.Microsoft.UI.Windowing.DisplayAreaFallback) -> win32more.Microsoft.UI.Windowing.DisplayArea: ...
    @winrt_classmethod
    def GetFromPoint(cls: win32more.Microsoft.UI.Windowing.IDisplayAreaStatics, point: win32more.Windows.Graphics.PointInt32, displayAreaFallback: win32more.Microsoft.UI.Windowing.DisplayAreaFallback) -> win32more.Microsoft.UI.Windowing.DisplayArea: ...
    @winrt_classmethod
    def GetFromRect(cls: win32more.Microsoft.UI.Windowing.IDisplayAreaStatics, rect: win32more.Windows.Graphics.RectInt32, displayAreaFallback: win32more.Microsoft.UI.Windowing.DisplayAreaFallback) -> win32more.Microsoft.UI.Windowing.DisplayArea: ...
    DisplayId = property(get_DisplayId, None)
    IsPrimary = property(get_IsPrimary, None)
    OuterBounds = property(get_OuterBounds, None)
    WorkArea = property(get_WorkArea, None)
    _DisplayArea_Meta_.Primary = property(get_Primary, None)
class DisplayAreaFallback(Enum, Int32):
    None_ = 0
    Primary = 1
    Nearest = 2
class DisplayAreaWatcher(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher
    _classid_ = 'Microsoft.UI.Windowing.DisplayAreaWatcher'
    @winrt_mixinmethod
    def add_Added(self: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.DisplayAreaWatcher, win32more.Microsoft.UI.Windowing.DisplayArea]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def Start(self: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher) -> Void: ...
    @winrt_mixinmethod
    def Stop(self: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher) -> Void: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher) -> win32more.Microsoft.UI.Windowing.DisplayAreaWatcherStatus: ...
    @winrt_mixinmethod
    def remove_Added(self: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_EnumerationCompleted(self: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.DisplayAreaWatcher, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_EnumerationCompleted(self: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Removed(self: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.DisplayAreaWatcher, win32more.Microsoft.UI.Windowing.DisplayArea]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Removed(self: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Stopped(self: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.DisplayAreaWatcher, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Stopped(self: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Updated(self: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.DisplayAreaWatcher, win32more.Microsoft.UI.Windowing.DisplayArea]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Updated(self: win32more.Microsoft.UI.Windowing.IDisplayAreaWatcher, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Status = property(get_Status, None)
    Added = event()
    EnumerationCompleted = event()
    Removed = event()
    Stopped = event()
    Updated = event()
class DisplayAreaWatcherStatus(Enum, Int32):
    Created = 0
    Started = 1
    EnumerationCompleted = 2
    Stopping = 3
    Stopped = 4
    Aborted = 5
class FullScreenPresenter(ComPtr):
    extends: win32more.Microsoft.UI.Windowing.AppWindowPresenter
    default_interface: win32more.Microsoft.UI.Windowing.IFullScreenPresenter
    _classid_ = 'Microsoft.UI.Windowing.FullScreenPresenter'
    @winrt_classmethod
    def Create(cls: win32more.Microsoft.UI.Windowing.IFullScreenPresenterStatics) -> win32more.Microsoft.UI.Windowing.FullScreenPresenter: ...
class IAppWindow(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IAppWindow'
    _iid_ = Guid('{cfa788b3-643b-5c5e-ad4e-321d48a82acd}')
    @winrt_commethod(6)
    def get_Id(self) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_commethod(7)
    def get_IsShownInSwitchers(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_IsShownInSwitchers(self, value: Boolean) -> Void: ...
    @winrt_commethod(9)
    def get_IsVisible(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_OwnerWindowId(self) -> win32more.Microsoft.UI.WindowId: ...
    @winrt_commethod(11)
    def get_Position(self) -> win32more.Windows.Graphics.PointInt32: ...
    @winrt_commethod(12)
    def get_Presenter(self) -> win32more.Microsoft.UI.Windowing.AppWindowPresenter: ...
    @winrt_commethod(13)
    def get_Size(self) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_commethod(14)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def put_Title(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(16)
    def get_TitleBar(self) -> win32more.Microsoft.UI.Windowing.AppWindowTitleBar: ...
    @winrt_commethod(17)
    def Destroy(self) -> Void: ...
    @winrt_commethod(18)
    def Hide(self) -> Void: ...
    @winrt_commethod(19)
    def Move(self, position: win32more.Windows.Graphics.PointInt32) -> Void: ...
    @winrt_commethod(20)
    def MoveAndResize(self, rect: win32more.Windows.Graphics.RectInt32) -> Void: ...
    @winrt_commethod(21)
    def MoveAndResizeRelativeToDisplayArea(self, rect: win32more.Windows.Graphics.RectInt32, displayarea: win32more.Microsoft.UI.Windowing.DisplayArea) -> Void: ...
    @winrt_commethod(22)
    def Resize(self, size: win32more.Windows.Graphics.SizeInt32) -> Void: ...
    @winrt_commethod(23)
    def SetIcon(self, iconPath: WinRT_String) -> Void: ...
    @winrt_commethod(24)
    def SetIconWithIconId(self, iconId: win32more.Microsoft.UI.IconId) -> Void: ...
    @winrt_commethod(25)
    def SetPresenter(self, appWindowPresenter: win32more.Microsoft.UI.Windowing.AppWindowPresenter) -> Void: ...
    @winrt_commethod(26)
    def SetPresenterByKind(self, appWindowPresenterKind: win32more.Microsoft.UI.Windowing.AppWindowPresenterKind) -> Void: ...
    @winrt_commethod(27)
    def Show(self) -> Void: ...
    @winrt_commethod(28)
    def ShowWithActivation(self, activateWindow: Boolean) -> Void: ...
    @winrt_commethod(29)
    def add_Changed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.AppWindow, win32more.Microsoft.UI.Windowing.AppWindowChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(30)
    def remove_Changed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(31)
    def add_Closing(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.AppWindow, win32more.Microsoft.UI.Windowing.AppWindowClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(32)
    def remove_Closing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(33)
    def add_Destroying(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.AppWindow, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(34)
    def remove_Destroying(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Id = property(get_Id, None)
    IsShownInSwitchers = property(get_IsShownInSwitchers, put_IsShownInSwitchers)
    IsVisible = property(get_IsVisible, None)
    OwnerWindowId = property(get_OwnerWindowId, None)
    Position = property(get_Position, None)
    Presenter = property(get_Presenter, None)
    Size = property(get_Size, None)
    Title = property(get_Title, put_Title)
    TitleBar = property(get_TitleBar, None)
    Changed = event()
    Closing = event()
    Destroying = event()
class IAppWindow2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IAppWindow2'
    _iid_ = Guid('{6cd41292-794c-5cac-8961-210d012c6ebc}')
    @winrt_commethod(6)
    def get_ClientSize(self) -> win32more.Windows.Graphics.SizeInt32: ...
    @winrt_commethod(7)
    def MoveInZOrderAtBottom(self) -> Void: ...
    @winrt_commethod(8)
    def MoveInZOrderAtTop(self) -> Void: ...
    @winrt_commethod(9)
    def MoveInZOrderBelow(self, windowId: win32more.Microsoft.UI.WindowId) -> Void: ...
    @winrt_commethod(10)
    def ResizeClient(self, size: win32more.Windows.Graphics.SizeInt32) -> Void: ...
    @winrt_commethod(11)
    def ShowOnceWithRequestedStartupState(self) -> Void: ...
    ClientSize = property(get_ClientSize, None)
class IAppWindow3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IAppWindow3'
    _iid_ = Guid('{2f260cea-193d-5dd6-a904-d7649a608d2f}')
    @winrt_commethod(6)
    def AssociateWithDispatcherQueue(self, dispatcherQueue: win32more.Microsoft.UI.Dispatching.DispatcherQueue) -> Void: ...
    @winrt_commethod(7)
    def get_DispatcherQueue(self) -> win32more.Microsoft.UI.Dispatching.DispatcherQueue: ...
    DispatcherQueue = property(get_DispatcherQueue, None)
class IAppWindowChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IAppWindowChangedEventArgs'
    _iid_ = Guid('{2182bc5d-fdac-5c3e-bf37-7d8d684e9d1d}')
    @winrt_commethod(6)
    def get_DidPositionChange(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_DidPresenterChange(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_DidSizeChange(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_DidVisibilityChange(self) -> Boolean: ...
    DidPositionChange = property(get_DidPositionChange, None)
    DidPresenterChange = property(get_DidPresenterChange, None)
    DidSizeChange = property(get_DidSizeChange, None)
    DidVisibilityChange = property(get_DidVisibilityChange, None)
class IAppWindowChangedEventArgs2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IAppWindowChangedEventArgs2'
    _iid_ = Guid('{a773ab4c-a5ec-50e8-98ac-247fe6cd4227}')
    @winrt_commethod(6)
    def get_DidZOrderChange(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_IsZOrderAtBottom(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_IsZOrderAtTop(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_ZOrderBelowWindowId(self) -> win32more.Microsoft.UI.WindowId: ...
    DidZOrderChange = property(get_DidZOrderChange, None)
    IsZOrderAtBottom = property(get_IsZOrderAtBottom, None)
    IsZOrderAtTop = property(get_IsZOrderAtTop, None)
    ZOrderBelowWindowId = property(get_ZOrderBelowWindowId, None)
class IAppWindowClosingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IAppWindowClosingEventArgs'
    _iid_ = Guid('{0e09d90b-2261-590b-9ad1-8504991d8754}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    Cancel = property(get_Cancel, put_Cancel)
class IAppWindowPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IAppWindowPresenter'
    _iid_ = Guid('{bc3042c2-c6c6-5632-8989-ff0ec6d3b40d}')
    @winrt_commethod(6)
    def get_Kind(self) -> win32more.Microsoft.UI.Windowing.AppWindowPresenterKind: ...
    Kind = property(get_Kind, None)
class IAppWindowPresenterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IAppWindowPresenterFactory'
    _iid_ = Guid('{62082e3c-1368-5238-90d1-e932dc718a82}')
class IAppWindowStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IAppWindowStatics'
    _iid_ = Guid('{3c315c24-d540-5d72-b518-b226b83627cb}')
    @winrt_commethod(6)
    def Create(self) -> win32more.Microsoft.UI.Windowing.AppWindow: ...
    @winrt_commethod(7)
    def CreateWithPresenter(self, appWindowPresenter: win32more.Microsoft.UI.Windowing.AppWindowPresenter) -> win32more.Microsoft.UI.Windowing.AppWindow: ...
    @winrt_commethod(8)
    def CreateWithPresenterAndOwner(self, appWindowPresenter: win32more.Microsoft.UI.Windowing.AppWindowPresenter, ownerWindowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.Windowing.AppWindow: ...
    @winrt_commethod(9)
    def GetFromWindowId(self, windowId: win32more.Microsoft.UI.WindowId) -> win32more.Microsoft.UI.Windowing.AppWindow: ...
class IAppWindowStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IAppWindowStatics2'
    _iid_ = Guid('{cabc23db-4606-5d6e-89a5-06de1d8bd3e2}')
    @winrt_commethod(6)
    def CreateWithDispatcherQueue(self, appWindowPresenter: win32more.Microsoft.UI.Windowing.AppWindowPresenter, ownerWindowId: win32more.Microsoft.UI.WindowId, DispatcherQueue: win32more.Microsoft.UI.Dispatching.DispatcherQueue) -> win32more.Microsoft.UI.Windowing.AppWindow: ...
class IAppWindowTitleBar(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IAppWindowTitleBar'
    _iid_ = Guid('{5574efa2-c91c-5700-a363-539c71a7aaf4}')
    @winrt_commethod(6)
    def get_BackgroundColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(7)
    def put_BackgroundColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(8)
    def get_ButtonBackgroundColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(9)
    def put_ButtonBackgroundColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(10)
    def get_ButtonForegroundColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(11)
    def put_ButtonForegroundColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(12)
    def get_ButtonHoverBackgroundColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(13)
    def put_ButtonHoverBackgroundColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(14)
    def get_ButtonHoverForegroundColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(15)
    def put_ButtonHoverForegroundColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(16)
    def get_ButtonInactiveBackgroundColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(17)
    def put_ButtonInactiveBackgroundColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(18)
    def get_ButtonInactiveForegroundColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(19)
    def put_ButtonInactiveForegroundColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(20)
    def get_ButtonPressedBackgroundColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(21)
    def put_ButtonPressedBackgroundColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(22)
    def get_ButtonPressedForegroundColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(23)
    def put_ButtonPressedForegroundColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(24)
    def get_ExtendsContentIntoTitleBar(self) -> Boolean: ...
    @winrt_commethod(25)
    def put_ExtendsContentIntoTitleBar(self, value: Boolean) -> Void: ...
    @winrt_commethod(26)
    def get_ForegroundColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(27)
    def put_ForegroundColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(28)
    def get_Height(self) -> Int32: ...
    @winrt_commethod(29)
    def get_IconShowOptions(self) -> win32more.Microsoft.UI.Windowing.IconShowOptions: ...
    @winrt_commethod(30)
    def put_IconShowOptions(self, value: win32more.Microsoft.UI.Windowing.IconShowOptions) -> Void: ...
    @winrt_commethod(31)
    def get_InactiveBackgroundColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(32)
    def put_InactiveBackgroundColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(33)
    def get_InactiveForegroundColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]: ...
    @winrt_commethod(34)
    def put_InactiveForegroundColor(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.UI.Color]) -> Void: ...
    @winrt_commethod(35)
    def get_LeftInset(self) -> Int32: ...
    @winrt_commethod(36)
    def get_RightInset(self) -> Int32: ...
    @winrt_commethod(37)
    def ResetToDefault(self) -> Void: ...
    @winrt_commethod(38)
    def SetDragRectangles(self, value: PassArray[win32more.Windows.Graphics.RectInt32]) -> Void: ...
    BackgroundColor = property(get_BackgroundColor, put_BackgroundColor)
    ButtonBackgroundColor = property(get_ButtonBackgroundColor, put_ButtonBackgroundColor)
    ButtonForegroundColor = property(get_ButtonForegroundColor, put_ButtonForegroundColor)
    ButtonHoverBackgroundColor = property(get_ButtonHoverBackgroundColor, put_ButtonHoverBackgroundColor)
    ButtonHoverForegroundColor = property(get_ButtonHoverForegroundColor, put_ButtonHoverForegroundColor)
    ButtonInactiveBackgroundColor = property(get_ButtonInactiveBackgroundColor, put_ButtonInactiveBackgroundColor)
    ButtonInactiveForegroundColor = property(get_ButtonInactiveForegroundColor, put_ButtonInactiveForegroundColor)
    ButtonPressedBackgroundColor = property(get_ButtonPressedBackgroundColor, put_ButtonPressedBackgroundColor)
    ButtonPressedForegroundColor = property(get_ButtonPressedForegroundColor, put_ButtonPressedForegroundColor)
    ExtendsContentIntoTitleBar = property(get_ExtendsContentIntoTitleBar, put_ExtendsContentIntoTitleBar)
    ForegroundColor = property(get_ForegroundColor, put_ForegroundColor)
    Height = property(get_Height, None)
    IconShowOptions = property(get_IconShowOptions, put_IconShowOptions)
    InactiveBackgroundColor = property(get_InactiveBackgroundColor, put_InactiveBackgroundColor)
    InactiveForegroundColor = property(get_InactiveForegroundColor, put_InactiveForegroundColor)
    LeftInset = property(get_LeftInset, None)
    RightInset = property(get_RightInset, None)
class IAppWindowTitleBar2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IAppWindowTitleBar2'
    _iid_ = Guid('{86faed38-748a-5b4b-9ccf-3ba0496c9041}')
    @winrt_commethod(6)
    def get_PreferredHeightOption(self) -> win32more.Microsoft.UI.Windowing.TitleBarHeightOption: ...
    @winrt_commethod(7)
    def put_PreferredHeightOption(self, value: win32more.Microsoft.UI.Windowing.TitleBarHeightOption) -> Void: ...
    PreferredHeightOption = property(get_PreferredHeightOption, put_PreferredHeightOption)
class IAppWindowTitleBarStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IAppWindowTitleBarStatics'
    _iid_ = Guid('{9e1da52e-8b15-54d6-a886-f7b9f9d930b2}')
    @winrt_commethod(6)
    def IsCustomizationSupported(self) -> Boolean: ...
class ICompactOverlayPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.ICompactOverlayPresenter'
    _iid_ = Guid('{efeb0812-6fc7-5b7d-bd92-cc8f9a6454c9}')
    @winrt_commethod(6)
    def get_InitialSize(self) -> win32more.Microsoft.UI.Windowing.CompactOverlaySize: ...
    @winrt_commethod(7)
    def put_InitialSize(self, value: win32more.Microsoft.UI.Windowing.CompactOverlaySize) -> Void: ...
    InitialSize = property(get_InitialSize, put_InitialSize)
class ICompactOverlayPresenterStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.ICompactOverlayPresenterStatics'
    _iid_ = Guid('{eab93186-4f6a-52f9-8c03-da57a1522f6e}')
    @winrt_commethod(6)
    def Create(self) -> win32more.Microsoft.UI.Windowing.CompactOverlayPresenter: ...
class IDisplayArea(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IDisplayArea'
    _iid_ = Guid('{5c7e0537-b621-5579-bcae-a84aa8746167}')
    @winrt_commethod(6)
    def get_DisplayId(self) -> win32more.Microsoft.UI.DisplayId: ...
    @winrt_commethod(7)
    def get_IsPrimary(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_OuterBounds(self) -> win32more.Windows.Graphics.RectInt32: ...
    @winrt_commethod(9)
    def get_WorkArea(self) -> win32more.Windows.Graphics.RectInt32: ...
    DisplayId = property(get_DisplayId, None)
    IsPrimary = property(get_IsPrimary, None)
    OuterBounds = property(get_OuterBounds, None)
    WorkArea = property(get_WorkArea, None)
class IDisplayAreaStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IDisplayAreaStatics'
    _iid_ = Guid('{02ab4926-211e-5d49-8e4b-2af193daed09}')
    @winrt_commethod(6)
    def get_Primary(self) -> win32more.Microsoft.UI.Windowing.DisplayArea: ...
    @winrt_commethod(7)
    def CreateWatcher(self) -> win32more.Microsoft.UI.Windowing.DisplayAreaWatcher: ...
    @winrt_commethod(8)
    def FindAll(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Windowing.DisplayArea]: ...
    @winrt_commethod(9)
    def GetFromWindowId(self, windowId: win32more.Microsoft.UI.WindowId, displayAreaFallback: win32more.Microsoft.UI.Windowing.DisplayAreaFallback) -> win32more.Microsoft.UI.Windowing.DisplayArea: ...
    @winrt_commethod(10)
    def GetFromPoint(self, point: win32more.Windows.Graphics.PointInt32, displayAreaFallback: win32more.Microsoft.UI.Windowing.DisplayAreaFallback) -> win32more.Microsoft.UI.Windowing.DisplayArea: ...
    @winrt_commethod(11)
    def GetFromRect(self, rect: win32more.Windows.Graphics.RectInt32, displayAreaFallback: win32more.Microsoft.UI.Windowing.DisplayAreaFallback) -> win32more.Microsoft.UI.Windowing.DisplayArea: ...
    Primary = property(get_Primary, None)
class IDisplayAreaStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IDisplayAreaStatics2'
    _iid_ = Guid('{7207ad4b-890d-5dd7-bc18-78ffd9544d8f}')
    @winrt_commethod(6)
    def GetFromDisplayId(self, displayId: win32more.Microsoft.UI.DisplayId) -> win32more.Microsoft.UI.Windowing.DisplayArea: ...
class IDisplayAreaWatcher(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IDisplayAreaWatcher'
    _iid_ = Guid('{83f6562f-d3a0-548b-8e4f-a99be3d95c9c}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Microsoft.UI.Windowing.DisplayAreaWatcherStatus: ...
    @winrt_commethod(7)
    def Start(self) -> Void: ...
    @winrt_commethod(8)
    def Stop(self) -> Void: ...
    @winrt_commethod(9)
    def add_Added(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.DisplayAreaWatcher, win32more.Microsoft.UI.Windowing.DisplayArea]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_Added(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def add_EnumerationCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.DisplayAreaWatcher, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_EnumerationCompleted(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(13)
    def add_Removed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.DisplayAreaWatcher, win32more.Microsoft.UI.Windowing.DisplayArea]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_Removed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(15)
    def add_Stopped(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.DisplayAreaWatcher, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_Stopped(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def add_Updated(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Microsoft.UI.Windowing.DisplayAreaWatcher, win32more.Microsoft.UI.Windowing.DisplayArea]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_Updated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Status = property(get_Status, None)
    Added = event()
    EnumerationCompleted = event()
    Removed = event()
    Stopped = event()
    Updated = event()
class IFullScreenPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IFullScreenPresenter'
    _iid_ = Guid('{fa9141fd-b8dd-5da1-8b2b-7cdadb76f593}')
class IFullScreenPresenterStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IFullScreenPresenterStatics'
    _iid_ = Guid('{2ec0d2c1-e086-55bb-a3b2-44942e231c67}')
    @winrt_commethod(6)
    def Create(self) -> win32more.Microsoft.UI.Windowing.FullScreenPresenter: ...
class IOverlappedPresenter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IOverlappedPresenter'
    _iid_ = Guid('{21693970-4f4c-5172-9e9d-682a2d174884}')
    @winrt_commethod(6)
    def get_HasBorder(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_HasTitleBar(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_IsAlwaysOnTop(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IsAlwaysOnTop(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_IsMaximizable(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsMaximizable(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_IsMinimizable(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsMinimizable(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_IsModal(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsModal(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_IsResizable(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsResizable(self, value: Boolean) -> Void: ...
    @winrt_commethod(18)
    def get_State(self) -> win32more.Microsoft.UI.Windowing.OverlappedPresenterState: ...
    @winrt_commethod(19)
    def Maximize(self) -> Void: ...
    @winrt_commethod(20)
    def Minimize(self) -> Void: ...
    @winrt_commethod(21)
    def Restore(self) -> Void: ...
    @winrt_commethod(22)
    def SetBorderAndTitleBar(self, hasBorder: Boolean, hasTitleBar: Boolean) -> Void: ...
    HasBorder = property(get_HasBorder, None)
    HasTitleBar = property(get_HasTitleBar, None)
    IsAlwaysOnTop = property(get_IsAlwaysOnTop, put_IsAlwaysOnTop)
    IsMaximizable = property(get_IsMaximizable, put_IsMaximizable)
    IsMinimizable = property(get_IsMinimizable, put_IsMinimizable)
    IsModal = property(get_IsModal, put_IsModal)
    IsResizable = property(get_IsResizable, put_IsResizable)
    State = property(get_State, None)
class IOverlappedPresenter2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IOverlappedPresenter2'
    _iid_ = Guid('{5c6ccd93-4244-5cd2-b355-ed5ea34df730}')
    @winrt_commethod(6)
    def MinimizeWithActivation(self, activateWindow: Boolean) -> Void: ...
    @winrt_commethod(7)
    def RestoreWithActivation(self, activateWindow: Boolean) -> Void: ...
class IOverlappedPresenterStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IOverlappedPresenterStatics'
    _iid_ = Guid('{997225e4-7b00-5aee-a4be-d4068d1999e2}')
    @winrt_commethod(6)
    def Create(self) -> win32more.Microsoft.UI.Windowing.OverlappedPresenter: ...
    @winrt_commethod(7)
    def CreateForContextMenu(self) -> win32more.Microsoft.UI.Windowing.OverlappedPresenter: ...
    @winrt_commethod(8)
    def CreateForDialog(self) -> win32more.Microsoft.UI.Windowing.OverlappedPresenter: ...
    @winrt_commethod(9)
    def CreateForToolWindow(self) -> win32more.Microsoft.UI.Windowing.OverlappedPresenter: ...
class IOverlappedPresenterStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Microsoft.UI.Windowing.IOverlappedPresenterStatics2'
    _iid_ = Guid('{ed5c4f92-32f4-5d15-80d0-b2a5efa04d39}')
    @winrt_commethod(6)
    def get_RequestedStartupState(self) -> win32more.Microsoft.UI.Windowing.OverlappedPresenterState: ...
    RequestedStartupState = property(get_RequestedStartupState, None)
class IconShowOptions(Enum, Int32):
    ShowIconAndSystemMenu = 0
    HideIconAndSystemMenu = 1
class _OverlappedPresenter_Meta_(ComPtr.__class__):
    pass
class OverlappedPresenter(ComPtr, metaclass=_OverlappedPresenter_Meta_):
    extends: win32more.Microsoft.UI.Windowing.AppWindowPresenter
    default_interface: win32more.Microsoft.UI.Windowing.IOverlappedPresenter
    _classid_ = 'Microsoft.UI.Windowing.OverlappedPresenter'
    @winrt_mixinmethod
    def Restore(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter) -> Void: ...
    @winrt_mixinmethod
    def get_HasTitleBar(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsAlwaysOnTop(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsAlwaysOnTop(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsMaximizable(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsMaximizable(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsMinimizable(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsMinimizable(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsModal(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsModal(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsResizable(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsResizable(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_State(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter) -> win32more.Microsoft.UI.Windowing.OverlappedPresenterState: ...
    @winrt_mixinmethod
    def Maximize(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter) -> Void: ...
    @winrt_mixinmethod
    def Minimize(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter) -> Void: ...
    @winrt_mixinmethod
    def get_HasBorder(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter) -> Boolean: ...
    @winrt_mixinmethod
    def SetBorderAndTitleBar(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter, hasBorder: Boolean, hasTitleBar: Boolean) -> Void: ...
    @winrt_mixinmethod
    def MinimizeWithActivation(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter2, activateWindow: Boolean) -> Void: ...
    @winrt_mixinmethod
    def RestoreWithActivation(self: win32more.Microsoft.UI.Windowing.IOverlappedPresenter2, activateWindow: Boolean) -> Void: ...
    @winrt_classmethod
    def get_RequestedStartupState(cls: win32more.Microsoft.UI.Windowing.IOverlappedPresenterStatics2) -> win32more.Microsoft.UI.Windowing.OverlappedPresenterState: ...
    @winrt_classmethod
    def Create(cls: win32more.Microsoft.UI.Windowing.IOverlappedPresenterStatics) -> win32more.Microsoft.UI.Windowing.OverlappedPresenter: ...
    @winrt_classmethod
    def CreateForContextMenu(cls: win32more.Microsoft.UI.Windowing.IOverlappedPresenterStatics) -> win32more.Microsoft.UI.Windowing.OverlappedPresenter: ...
    @winrt_classmethod
    def CreateForDialog(cls: win32more.Microsoft.UI.Windowing.IOverlappedPresenterStatics) -> win32more.Microsoft.UI.Windowing.OverlappedPresenter: ...
    @winrt_classmethod
    def CreateForToolWindow(cls: win32more.Microsoft.UI.Windowing.IOverlappedPresenterStatics) -> win32more.Microsoft.UI.Windowing.OverlappedPresenter: ...
    HasBorder = property(get_HasBorder, None)
    HasTitleBar = property(get_HasTitleBar, None)
    IsAlwaysOnTop = property(get_IsAlwaysOnTop, put_IsAlwaysOnTop)
    IsMaximizable = property(get_IsMaximizable, put_IsMaximizable)
    IsMinimizable = property(get_IsMinimizable, put_IsMinimizable)
    IsModal = property(get_IsModal, put_IsModal)
    IsResizable = property(get_IsResizable, put_IsResizable)
    State = property(get_State, None)
    _OverlappedPresenter_Meta_.RequestedStartupState = property(get_RequestedStartupState, None)
class OverlappedPresenterState(Enum, Int32):
    Maximized = 0
    Minimized = 1
    Restored = 2
class TitleBarHeightOption(Enum, Int32):
    Standard = 0
    Tall = 1
    Collapsed = 2


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Wallet
import win32more.Windows.ApplicationModel.Wallet.System
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class IWalletItemSystemStore(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.System.IWalletItemSystemStore'
    _iid_ = Guid('{522e2bff-96a2-4a17-8d19-fe1d9f837561}')
    @winrt_commethod(6)
    def GetItemsAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Wallet.WalletItem]]: ...
    @winrt_commethod(7)
    def DeleteAsync(self, item: win32more.Windows.ApplicationModel.Wallet.WalletItem) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(8)
    def ImportItemAsync(self, stream: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Wallet.WalletItem]: ...
    @winrt_commethod(9)
    def GetAppStatusForItem(self, item: win32more.Windows.ApplicationModel.Wallet.WalletItem) -> win32more.Windows.ApplicationModel.Wallet.System.WalletItemAppAssociation: ...
    @winrt_commethod(10)
    def LaunchAppForItemAsync(self, item: win32more.Windows.ApplicationModel.Wallet.WalletItem) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
class IWalletItemSystemStore2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.System.IWalletItemSystemStore2'
    _iid_ = Guid('{f98d3a4e-be00-4fdd-9734-6c113c1ac1cb}')
    @winrt_commethod(6)
    def add_ItemsChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Wallet.System.WalletItemSystemStore, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_ItemsChanged(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ItemsChanged = event()
class IWalletManagerSystemStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.System.IWalletManagerSystemStatics'
    _iid_ = Guid('{bee8eb89-2634-4b9a-8b23-ee8903c91fe0}')
    @winrt_commethod(6)
    def RequestStoreAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Wallet.System.WalletItemSystemStore]: ...
class WalletItemAppAssociation(Enum, Int32):
    None_ = 0
    AppInstalled = 1
    AppNotInstalled = 2
class WalletItemSystemStore(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Wallet.System.IWalletItemSystemStore
    _classid_ = 'Windows.ApplicationModel.Wallet.System.WalletItemSystemStore'
    @winrt_mixinmethod
    def GetItemsAsync(self: win32more.Windows.ApplicationModel.Wallet.System.IWalletItemSystemStore) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Wallet.WalletItem]]: ...
    @winrt_mixinmethod
    def DeleteAsync(self: win32more.Windows.ApplicationModel.Wallet.System.IWalletItemSystemStore, item: win32more.Windows.ApplicationModel.Wallet.WalletItem) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ImportItemAsync(self: win32more.Windows.ApplicationModel.Wallet.System.IWalletItemSystemStore, stream: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Wallet.WalletItem]: ...
    @winrt_mixinmethod
    def GetAppStatusForItem(self: win32more.Windows.ApplicationModel.Wallet.System.IWalletItemSystemStore, item: win32more.Windows.ApplicationModel.Wallet.WalletItem) -> win32more.Windows.ApplicationModel.Wallet.System.WalletItemAppAssociation: ...
    @winrt_mixinmethod
    def LaunchAppForItemAsync(self: win32more.Windows.ApplicationModel.Wallet.System.IWalletItemSystemStore, item: win32more.Windows.ApplicationModel.Wallet.WalletItem) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def add_ItemsChanged(self: win32more.Windows.ApplicationModel.Wallet.System.IWalletItemSystemStore2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Wallet.System.WalletItemSystemStore, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ItemsChanged(self: win32more.Windows.ApplicationModel.Wallet.System.IWalletItemSystemStore2, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ItemsChanged = event()
class WalletManagerSystem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.System.WalletManagerSystem'
    @winrt_classmethod
    def RequestStoreAsync(cls: win32more.Windows.ApplicationModel.Wallet.System.IWalletManagerSystemStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Wallet.System.WalletItemSystemStore]: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Storage.DataDeduplication
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Variant
DEDUP_CHUNKLIB_MAX_CHUNKS_ENUM: UInt32 = 1024
class DDP_FILE_EXTENT(Structure):
    Length: Int64
    Offset: Int64
DEDUP_BACKUP_SUPPORT_PARAM_TYPE = Int32
DEDUP_RECONSTRUCT_UNOPTIMIZED: win32more.Windows.Win32.Storage.DataDeduplication.DEDUP_BACKUP_SUPPORT_PARAM_TYPE = 1
DEDUP_RECONSTRUCT_OPTIMIZED: win32more.Windows.Win32.Storage.DataDeduplication.DEDUP_BACKUP_SUPPORT_PARAM_TYPE = 2
class DEDUP_CHUNK_INFO_HASH32(Structure):
    ChunkFlags: UInt32
    ChunkOffsetInStream: UInt64
    ChunkSize: UInt64
    HashVal: Byte * 32
class DEDUP_CONTAINER_EXTENT(Structure):
    ContainerIndex: UInt32
    StartOffset: Int64
    Length: Int64
DEDUP_SET_PARAM_TYPE = Int32
DEDUP_PT_MinChunkSizeBytes: win32more.Windows.Win32.Storage.DataDeduplication.DEDUP_SET_PARAM_TYPE = 1
DEDUP_PT_MaxChunkSizeBytes: win32more.Windows.Win32.Storage.DataDeduplication.DEDUP_SET_PARAM_TYPE = 2
DEDUP_PT_AvgChunkSizeBytes: win32more.Windows.Win32.Storage.DataDeduplication.DEDUP_SET_PARAM_TYPE = 3
DEDUP_PT_InvariantChunking: win32more.Windows.Win32.Storage.DataDeduplication.DEDUP_SET_PARAM_TYPE = 4
DEDUP_PT_DisableStrongHashComputation: win32more.Windows.Win32.Storage.DataDeduplication.DEDUP_SET_PARAM_TYPE = 5
DedupBackupSupport = Guid('{73d6b2ad-2984-4715-b2e3-924c149744dd}')
class DedupChunk(Structure):
    Hash: win32more.Windows.Win32.Storage.DataDeduplication.DedupHash
    Flags: win32more.Windows.Win32.Storage.DataDeduplication.DedupChunkFlags
    LogicalSize: UInt32
    DataSize: UInt32
DedupChunkFlags = Int32
DedupChunkFlags_None: win32more.Windows.Win32.Storage.DataDeduplication.DedupChunkFlags = 0
DedupChunkFlags_Compressed: win32more.Windows.Win32.Storage.DataDeduplication.DedupChunkFlags = 1
DedupChunkingAlgorithm = Int32
DedupChunkingAlgorithm_Unknonwn: win32more.Windows.Win32.Storage.DataDeduplication.DedupChunkingAlgorithm = 0
DedupChunkingAlgorithm_V1: win32more.Windows.Win32.Storage.DataDeduplication.DedupChunkingAlgorithm = 1
DedupCompressionAlgorithm = Int32
DedupCompressionAlgorithm_Unknonwn: win32more.Windows.Win32.Storage.DataDeduplication.DedupCompressionAlgorithm = 0
DedupCompressionAlgorithm_Xpress: win32more.Windows.Win32.Storage.DataDeduplication.DedupCompressionAlgorithm = 1
DedupDataPort = Guid('{8f107207-1829-48b2-a64b-e61f8e0d9acb}')
DedupDataPortManagerOption = Int32
DedupDataPortManagerOption_None: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortManagerOption = 0
DedupDataPortManagerOption_AutoStart: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortManagerOption = 1
DedupDataPortManagerOption_SkipReconciliation: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortManagerOption = 2
DedupDataPortRequestStatus = Int32
DedupDataPortRequestStatus_Unknown: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortRequestStatus = 0
DedupDataPortRequestStatus_Queued: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortRequestStatus = 1
DedupDataPortRequestStatus_Processing: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortRequestStatus = 2
DedupDataPortRequestStatus_Partial: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortRequestStatus = 3
DedupDataPortRequestStatus_Complete: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortRequestStatus = 4
DedupDataPortRequestStatus_Failed: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortRequestStatus = 5
DedupDataPortVolumeStatus = Int32
DedupDataPortVolumeStatus_Unknown: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortVolumeStatus = 0
DedupDataPortVolumeStatus_NotEnabled: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortVolumeStatus = 1
DedupDataPortVolumeStatus_NotAvailable: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortVolumeStatus = 2
DedupDataPortVolumeStatus_Initializing: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortVolumeStatus = 3
DedupDataPortVolumeStatus_Ready: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortVolumeStatus = 4
DedupDataPortVolumeStatus_Maintenance: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortVolumeStatus = 5
DedupDataPortVolumeStatus_Shutdown: win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortVolumeStatus = 6
class DedupHash(Structure):
    Hash: Byte * 32
DedupHashingAlgorithm = Int32
DedupHashingAlgorithm_Unknonwn: win32more.Windows.Win32.Storage.DataDeduplication.DedupHashingAlgorithm = 0
DedupHashingAlgorithm_V1: win32more.Windows.Win32.Storage.DataDeduplication.DedupHashingAlgorithm = 1
class DedupStream(Structure):
    Path: win32more.Windows.Win32.Foundation.BSTR
    Offset: UInt64
    Length: UInt64
    ChunkCount: UInt32
class DedupStreamEntry(Structure):
    Hash: win32more.Windows.Win32.Storage.DataDeduplication.DedupHash
    LogicalSize: UInt32
    Offset: UInt64
class IDedupBackupSupport(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{c719d963-2b2d-415e-acf7-7eb7ca596ff4}')
    @commethod(3)
    def RestoreFiles(self, NumberOfFiles: UInt32, FileFullPaths: POINTER(win32more.Windows.Win32.Foundation.BSTR), Store: win32more.Windows.Win32.Storage.DataDeduplication.IDedupReadFileCallback, Flags: UInt32, FileResults: POINTER(win32more.Windows.Win32.Foundation.HRESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDedupChunkLibrary(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{bb5144d7-2720-4dcc-8777-78597416ec23}')
    @commethod(3)
    def InitializeForPushBuffers(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Uninitialize(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def SetParameter(self, dwParamType: UInt32, vParamValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def StartChunking(self, iidIteratorInterfaceID: Guid, ppChunksEnum: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDedupDataPort(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7963d734-40a9-4ea3-bbf6-5a89d26f7ae8}')
    @commethod(3)
    def GetStatus(self, pStatus: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortVolumeStatus), pDataHeadroomMb: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def LookupChunks(self, Count: UInt32, pHashes: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupHash), pRequestId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def InsertChunks(self, ChunkCount: UInt32, pChunkMetadata: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupChunk), DataByteCount: UInt32, pChunkData: POINTER(Byte), pRequestId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def InsertChunksWithStream(self, ChunkCount: UInt32, pChunkMetadata: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupChunk), DataByteCount: UInt32, pChunkDataStream: win32more.Windows.Win32.System.Com.IStream, pRequestId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CommitStreams(self, StreamCount: UInt32, pStreams: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupStream), EntryCount: UInt32, pEntries: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupStreamEntry), pRequestId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CommitStreamsWithStream(self, StreamCount: UInt32, pStreams: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupStream), EntryCount: UInt32, pEntriesStream: win32more.Windows.Win32.System.Com.IStream, pRequestId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetStreams(self, StreamCount: UInt32, pStreamPaths: POINTER(win32more.Windows.Win32.Foundation.BSTR), pRequestId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetStreamsResults(self, RequestId: Guid, MaxWaitMs: UInt32, StreamEntryIndex: UInt32, pStreamCount: POINTER(UInt32), ppStreams: POINTER(POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupStream)), pEntryCount: POINTER(UInt32), ppEntries: POINTER(POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupStreamEntry)), pStatus: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortRequestStatus), ppItemResults: POINTER(POINTER(win32more.Windows.Win32.Foundation.HRESULT))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetChunks(self, Count: UInt32, pHashes: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupHash), pRequestId: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetChunksResults(self, RequestId: Guid, MaxWaitMs: UInt32, ChunkIndex: UInt32, pChunkCount: POINTER(UInt32), ppChunkMetadata: POINTER(POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupChunk)), pDataByteCount: POINTER(UInt32), ppChunkData: POINTER(POINTER(Byte)), pStatus: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortRequestStatus), ppItemResults: POINTER(POINTER(win32more.Windows.Win32.Foundation.HRESULT))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetRequestStatus(self, RequestId: Guid, pStatus: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortRequestStatus)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetRequestResults(self, RequestId: Guid, MaxWaitMs: UInt32, pBatchResult: POINTER(win32more.Windows.Win32.Foundation.HRESULT), pBatchCount: POINTER(UInt32), pStatus: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortRequestStatus), ppItemResults: POINTER(POINTER(win32more.Windows.Win32.Foundation.HRESULT))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDedupDataPortManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{44677452-b90a-445e-8192-cdcfe81511fb}')
    @commethod(3)
    def GetConfiguration(self, pMinChunkSize: POINTER(UInt32), pMaxChunkSize: POINTER(UInt32), pChunkingAlgorithm: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupChunkingAlgorithm), pHashingAlgorithm: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupHashingAlgorithm), pCompressionAlgorithm: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupCompressionAlgorithm)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetVolumeStatus(self, Options: UInt32, Path: win32more.Windows.Win32.Foundation.BSTR, pStatus: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DedupDataPortVolumeStatus)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetVolumeDataPort(self, Options: UInt32, Path: win32more.Windows.Win32.Foundation.BSTR, ppDataPort: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.IDedupDataPort)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDedupIterateChunksHash32(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{90b584d3-72aa-400f-9767-cad866a5a2d8}')
    @commethod(3)
    def PushBuffer(self, pBuffer: POINTER(Byte), ulBufferLength: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Next(self, ulMaxChunks: UInt32, pArrChunks: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DEDUP_CHUNK_INFO_HASH32), pulFetched: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Drain(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Reset(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDedupReadFileCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{7bacc67a-2f1d-42d0-897e-6ff62dd533bb}')
    @commethod(3)
    def ReadBackupFile(self, FileFullPath: win32more.Windows.Win32.Foundation.BSTR, FileOffset: Int64, SizeToRead: UInt32, FileBuffer: POINTER(Byte), ReturnedSize: POINTER(UInt32), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def OrderContainersRestore(self, NumberOfContainers: UInt32, ContainerPaths: POINTER(win32more.Windows.Win32.Foundation.BSTR), ReadPlanEntries: POINTER(UInt32), ReadPlan: POINTER(POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DEDUP_CONTAINER_EXTENT))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def PreviewContainerRead(self, FileFullPath: win32more.Windows.Win32.Foundation.BSTR, NumberOfReads: UInt32, ReadOffsets: POINTER(win32more.Windows.Win32.Storage.DataDeduplication.DDP_FILE_EXTENT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Diagnostics.Debug
import win32more.Windows.Win32.System.Kernel
import win32more.Windows.Win32.System.VirtualDosMachines
VDMCONTEXT_i386: UInt32 = 65536
VDMCONTEXT_i486: UInt32 = 65536
VDM_KGDT_R3_CODE: UInt32 = 24
VDM_MAXIMUM_SUPPORTED_EXTENSION: UInt32 = 512
V86FLAGS_CARRY: UInt32 = 1
V86FLAGS_PARITY: UInt32 = 4
V86FLAGS_AUXCARRY: UInt32 = 16
V86FLAGS_ZERO: UInt32 = 64
V86FLAGS_SIGN: UInt32 = 128
V86FLAGS_TRACE: UInt32 = 256
V86FLAGS_INTERRUPT: UInt32 = 512
V86FLAGS_DIRECTION: UInt32 = 1024
V86FLAGS_OVERFLOW: UInt32 = 2048
V86FLAGS_IOPL: UInt32 = 12288
V86FLAGS_IOPL_BITS: UInt32 = 18
V86FLAGS_RESUME: UInt32 = 65536
V86FLAGS_V86: UInt32 = 131072
V86FLAGS_ALIGNMENT: UInt32 = 262144
STATUS_VDM_EVENT: Int32 = 1073741829
DBG_SEGLOAD: UInt32 = 0
DBG_SEGMOVE: UInt32 = 1
DBG_SEGFREE: UInt32 = 2
DBG_MODLOAD: UInt32 = 3
DBG_MODFREE: UInt32 = 4
DBG_SINGLESTEP: UInt32 = 5
DBG_BREAK: UInt32 = 6
DBG_GPFAULT: UInt32 = 7
DBG_DIVOVERFLOW: UInt32 = 8
DBG_INSTRFAULT: UInt32 = 9
DBG_TASKSTART: UInt32 = 10
DBG_TASKSTOP: UInt32 = 11
DBG_DLLSTART: UInt32 = 12
DBG_DLLSTOP: UInt32 = 13
DBG_ATTACH: UInt32 = 14
DBG_TOOLHELP: UInt32 = 15
DBG_STACKFAULT: UInt32 = 16
DBG_WOWINIT: UInt32 = 17
DBG_TEMPBP: UInt32 = 18
DBG_MODMOVE: UInt32 = 19
DBG_INIT: UInt32 = 20
DBG_GPFAULT2: UInt32 = 21
VDMEVENT_NEEDS_INTERACTIVE: UInt32 = 32768
VDMEVENT_VERBOSE: UInt32 = 16384
VDMEVENT_PE: UInt32 = 8192
VDMEVENT_ALLFLAGS: UInt32 = 57344
VDMEVENT_V86: UInt32 = 1
VDMEVENT_PM16: UInt32 = 2
MAX_MODULE_NAME: UInt32 = 9
MAX_PATH16: UInt32 = 255
SN_CODE: UInt32 = 0
SN_DATA: UInt32 = 1
SN_V86: UInt32 = 2
GLOBAL_ALL: UInt32 = 0
GLOBAL_LRU: UInt32 = 1
GLOBAL_FREE: UInt32 = 2
GT_UNKNOWN: UInt32 = 0
GT_DGROUP: UInt32 = 1
GT_DATA: UInt32 = 2
GT_CODE: UInt32 = 3
GT_TASK: UInt32 = 4
GT_RESOURCE: UInt32 = 5
GT_MODULE: UInt32 = 6
GT_FREE: UInt32 = 7
GT_INTERNAL: UInt32 = 8
GT_SENTINEL: UInt32 = 9
GT_BURGERMASTER: UInt32 = 10
GD_USERDEFINED: UInt32 = 0
GD_CURSORCOMPONENT: UInt32 = 1
GD_BITMAP: UInt32 = 2
GD_ICONCOMPONENT: UInt32 = 3
GD_MENU: UInt32 = 4
GD_DIALOG: UInt32 = 5
GD_STRING: UInt32 = 6
GD_FONTDIR: UInt32 = 7
GD_FONT: UInt32 = 8
GD_ACCELERATORS: UInt32 = 9
GD_RCDATA: UInt32 = 10
GD_ERRTABLE: UInt32 = 11
GD_CURSOR: UInt32 = 12
GD_ICON: UInt32 = 14
GD_NAMETABLE: UInt32 = 15
GD_MAX_RESOURCE: UInt32 = 15
WOW_SYSTEM: UInt32 = 1
VDMDBG_BREAK_DOSTASK: UInt32 = 1
VDMDBG_BREAK_WOWTASK: UInt32 = 2
VDMDBG_BREAK_LOADDLL: UInt32 = 4
VDMDBG_BREAK_EXCEPTIONS: UInt32 = 8
VDMDBG_BREAK_DEBUGGER: UInt32 = 16
VDMDBG_TRACE_HISTORY: UInt32 = 128
VDMDBG_BREAK_DIVIDEBYZERO: UInt32 = 256
VDMDBG_INITIAL_FLAGS: UInt32 = 256
VDMDBG_MAX_SYMBOL_BUFFER: UInt32 = 256
VDMADDR_V86: UInt32 = 2
VDMADDR_PM16: UInt32 = 4
VDMADDR_PM32: UInt32 = 16
@winfunctype_pointer
def DEBUGEVENTPROC(param0: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.DEBUG_EVENT), param1: VoidPtr) -> UInt32: ...
class GLOBALENTRY(Structure):
    dwSize: UInt32
    dwAddress: UInt32
    dwBlockSize: UInt32
    hBlock: win32more.Windows.Win32.Foundation.HANDLE
    wcLock: UInt16
    wcPageLock: UInt16
    wFlags: UInt16
    wHeapPresent: win32more.Windows.Win32.Foundation.BOOL
    hOwner: win32more.Windows.Win32.Foundation.HANDLE
    wType: UInt16
    wData: UInt16
    dwNext: UInt32
    dwNextAlt: UInt32
    _pack_ = 4
class IMAGE_NOTE(Structure):
    Module: win32more.Windows.Win32.Foundation.CHAR * 10
    FileName: win32more.Windows.Win32.Foundation.CHAR * 256
    hModule: UInt16
    hTask: UInt16
class MODULEENTRY(Structure):
    dwSize: UInt32
    szModule: win32more.Windows.Win32.Foundation.CHAR * 10
    hModule: win32more.Windows.Win32.Foundation.HANDLE
    wcUsage: UInt16
    szExePath: win32more.Windows.Win32.Foundation.CHAR * 256
    wNext: UInt16
    _pack_ = 4
@winfunctype_pointer
def PROCESSENUMPROC(dwProcessId: UInt32, dwAttributes: UInt32, lpUserDefined: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
class SEGMENT_NOTE(Structure):
    Selector1: UInt16
    Selector2: UInt16
    Segment: UInt16
    Module: win32more.Windows.Win32.Foundation.CHAR * 10
    FileName: win32more.Windows.Win32.Foundation.CHAR * 256
    Type: UInt16
    Length: UInt32
@winfunctype_pointer
def TASKENUMPROC(dwThreadId: UInt32, hMod16: UInt16, hTask16: UInt16, lpUserDefined: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def TASKENUMPROCEX(dwThreadId: UInt32, hMod16: UInt16, hTask16: UInt16, pszModName: POINTER(SByte), pszFileName: POINTER(SByte), lpUserDefined: win32more.Windows.Win32.Foundation.LPARAM) -> win32more.Windows.Win32.Foundation.BOOL: ...
class TEMP_BP_NOTE(Structure):
    Seg: UInt16
    Offset: UInt32
    bPM: win32more.Windows.Win32.Foundation.BOOL
@winfunctype_pointer
def VDMBREAKTHREADPROC(param0: win32more.Windows.Win32.Foundation.HANDLE) -> win32more.Windows.Win32.Foundation.BOOL: ...
if ARCH in 'X64,ARM64':
    class VDMCONTEXT(Structure):
        ContextFlags: UInt32
        Dr0: UInt32
        Dr1: UInt32
        Dr2: UInt32
        Dr3: UInt32
        Dr6: UInt32
        Dr7: UInt32
        FloatSave: win32more.Windows.Win32.System.Kernel.FLOATING_SAVE_AREA
        SegGs: UInt32
        SegFs: UInt32
        SegEs: UInt32
        SegDs: UInt32
        Edi: UInt32
        Esi: UInt32
        Ebx: UInt32
        Edx: UInt32
        Ecx: UInt32
        Eax: UInt32
        Ebp: UInt32
        Eip: UInt32
        SegCs: UInt32
        EFlags: UInt32
        Esp: UInt32
        SegSs: UInt32
        ExtendedRegisters: Byte * 512
class VDMCONTEXT_WITHOUT_XSAVE(Structure):
    ContextFlags: UInt32
    Dr0: UInt32
    Dr1: UInt32
    Dr2: UInt32
    Dr3: UInt32
    Dr6: UInt32
    Dr7: UInt32
    FloatSave: win32more.Windows.Win32.System.Kernel.FLOATING_SAVE_AREA
    SegGs: UInt32
    SegFs: UInt32
    SegEs: UInt32
    SegDs: UInt32
    Edi: UInt32
    Esi: UInt32
    Ebx: UInt32
    Edx: UInt32
    Ecx: UInt32
    Eax: UInt32
    Ebp: UInt32
    Eip: UInt32
    SegCs: UInt32
    EFlags: UInt32
    Esp: UInt32
    SegSs: UInt32
@winfunctype_pointer
def VDMDETECTWOWPROC() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMENUMPROCESSWOWPROC(param0: win32more.Windows.Win32.System.VirtualDosMachines.PROCESSENUMPROC, param1: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype_pointer
def VDMENUMTASKWOWEXPROC(param0: UInt32, param1: win32more.Windows.Win32.System.VirtualDosMachines.TASKENUMPROCEX, param2: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype_pointer
def VDMENUMTASKWOWPROC(param0: UInt32, param1: win32more.Windows.Win32.System.VirtualDosMachines.TASKENUMPROC, param2: win32more.Windows.Win32.Foundation.LPARAM) -> Int32: ...
@winfunctype_pointer
def VDMGETADDREXPRESSIONPROC(param0: win32more.Windows.Win32.Foundation.PSTR, param1: win32more.Windows.Win32.Foundation.PSTR, param2: POINTER(UInt16), param3: POINTER(UInt32), param4: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.BOOL: ...
if ARCH in 'X64,ARM64':
    @winfunctype_pointer
    def VDMGETCONTEXTPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: POINTER(win32more.Windows.Win32.System.VirtualDosMachines.VDMCONTEXT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
elif ARCH in 'X86':
    @winfunctype_pointer
    def VDMGETCONTEXTPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.CONTEXT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMGETDBGFLAGSPROC(param0: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype_pointer
def VDMGETMODULESELECTORPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: UInt32, param3: win32more.Windows.Win32.Foundation.PSTR, param4: POINTER(UInt16)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMGETPOINTERPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: UInt16, param3: UInt32, param4: win32more.Windows.Win32.Foundation.BOOL) -> UInt32: ...
@winfunctype_pointer
def VDMGETSEGMENTINFOPROC(param0: UInt16, param1: UInt32, param2: win32more.Windows.Win32.Foundation.BOOL, param3: win32more.Windows.Win32.System.VirtualDosMachines.VDM_SEGINFO) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMGETSELECTORMODULEPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: UInt16, param3: POINTER(UInt32), param4: win32more.Windows.Win32.Foundation.PSTR, param5: UInt32, param6: win32more.Windows.Win32.Foundation.PSTR, param7: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMGETSYMBOLPROC(param0: win32more.Windows.Win32.Foundation.PSTR, param1: UInt16, param2: UInt32, param3: win32more.Windows.Win32.Foundation.BOOL, param4: win32more.Windows.Win32.Foundation.BOOL, param5: win32more.Windows.Win32.Foundation.PSTR, param6: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
if ARCH in 'X64,ARM64':
    @winfunctype_pointer
    def VDMGETTHREADSELECTORENTRYPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: UInt32, param3: POINTER(win32more.Windows.Win32.System.VirtualDosMachines.VDMLDT_ENTRY)) -> win32more.Windows.Win32.Foundation.BOOL: ...
elif ARCH in 'X86':
    @winfunctype_pointer
    def VDMGETTHREADSELECTORENTRYPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: UInt32, param3: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.LDT_ENTRY)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMGLOBALFIRSTPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: POINTER(win32more.Windows.Win32.System.VirtualDosMachines.GLOBALENTRY), param3: UInt16, param4: win32more.Windows.Win32.System.VirtualDosMachines.DEBUGEVENTPROC, param5: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMGLOBALNEXTPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: POINTER(win32more.Windows.Win32.System.VirtualDosMachines.GLOBALENTRY), param3: UInt16, param4: win32more.Windows.Win32.System.VirtualDosMachines.DEBUGEVENTPROC, param5: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMISMODULELOADEDPROC(param0: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMKILLWOWPROC() -> win32more.Windows.Win32.Foundation.BOOL: ...
if ARCH in 'X64,ARM64':
    class VDMLDT_ENTRY(Structure):
        LimitLow: UInt16
        BaseLow: UInt16
        HighWord: _HighWord_e__Union
        class _HighWord_e__Union(Union):
            Bytes: _Bytes_e__Struct
            Bits: _Bits_e__Struct
            class _Bytes_e__Struct(Structure):
                BaseMid: Byte
                Flags1: Byte
                Flags2: Byte
                BaseHi: Byte
            class _Bits_e__Struct(Structure):
                BaseMid: Annotated[UInt32, 8]
                Type: Annotated[UInt32, 5]
                Dpl: Annotated[UInt32, 2]
                Pres: Annotated[UInt32, 1]
                LimitHi: Annotated[UInt32, 4]
                Sys: Annotated[UInt32, 1]
                Reserved_0: Annotated[UInt32, 1]
                Default_Big: Annotated[UInt32, 1]
                Granularity: Annotated[UInt32, 1]
                BaseHi: Annotated[UInt32, 8]
@winfunctype_pointer
def VDMMODULEFIRSTPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: POINTER(win32more.Windows.Win32.System.VirtualDosMachines.MODULEENTRY), param3: win32more.Windows.Win32.System.VirtualDosMachines.DEBUGEVENTPROC, param4: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMMODULENEXTPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: POINTER(win32more.Windows.Win32.System.VirtualDosMachines.MODULEENTRY), param3: win32more.Windows.Win32.System.VirtualDosMachines.DEBUGEVENTPROC, param4: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMPROCESSEXCEPTIONPROC(param0: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.DEBUG_EVENT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
if ARCH in 'X64,ARM64':
    @winfunctype_pointer
    def VDMSETCONTEXTPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: POINTER(win32more.Windows.Win32.System.VirtualDosMachines.VDMCONTEXT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
elif ARCH in 'X86':
    @winfunctype_pointer
    def VDMSETCONTEXTPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: win32more.Windows.Win32.Foundation.HANDLE, param2: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.CONTEXT)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMSETDBGFLAGSPROC(param0: win32more.Windows.Win32.Foundation.HANDLE, param1: UInt32) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMSTARTTASKINWOWPROC(param0: UInt32, param1: win32more.Windows.Win32.Foundation.PSTR, param2: UInt16) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def VDMTERMINATETASKINWOWPROC(param0: UInt32, param1: UInt16) -> win32more.Windows.Win32.Foundation.BOOL: ...
class VDM_SEGINFO(Structure):
    Selector: UInt16
    SegNumber: UInt16
    Length: UInt32
    Type: UInt16
    ModuleName: win32more.Windows.Win32.Foundation.CHAR * 9
    FileName: win32more.Windows.Win32.Foundation.CHAR * 255


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Mapi
MAPI_OLE: UInt32 = 1
MAPI_OLE_STATIC: UInt32 = 2
MAPI_ORIG: UInt32 = 0
MAPI_TO: UInt32 = 1
MAPI_CC: UInt32 = 2
MAPI_BCC: UInt32 = 3
MAPI_UNREAD: UInt32 = 1
MAPI_RECEIPT_REQUESTED: UInt32 = 2
MAPI_SENT: UInt32 = 4
MAPI_LOGON_UI: UInt32 = 1
MAPI_PASSWORD_UI: UInt32 = 131072
MAPI_NEW_SESSION: UInt32 = 2
MAPI_FORCE_DOWNLOAD: UInt32 = 4096
MAPI_EXTENDED: UInt32 = 32
MAPI_DIALOG: UInt32 = 8
MAPI_FORCE_UNICODE: UInt32 = 262144
MAPI_UNREAD_ONLY: UInt32 = 32
MAPI_GUARANTEE_FIFO: UInt32 = 256
MAPI_LONG_MSGID: UInt32 = 16384
MAPI_PEEK: UInt32 = 128
MAPI_SUPPRESS_ATTACH: UInt32 = 2048
MAPI_ENVELOPE_ONLY: UInt32 = 64
MAPI_BODY_AS_FILE: UInt32 = 512
MAPI_AB_NOMODIFY: UInt32 = 1024
SUCCESS_SUCCESS: UInt32 = 0
MAPI_USER_ABORT: UInt32 = 1
MAPI_E_USER_ABORT: UInt32 = 1
MAPI_E_FAILURE: UInt32 = 2
MAPI_E_LOGON_FAILURE: UInt32 = 3
MAPI_E_LOGIN_FAILURE: UInt32 = 3
MAPI_E_DISK_FULL: UInt32 = 4
MAPI_E_INSUFFICIENT_MEMORY: UInt32 = 5
MAPI_E_ACCESS_DENIED: UInt32 = 6
MAPI_E_TOO_MANY_SESSIONS: UInt32 = 8
MAPI_E_TOO_MANY_FILES: UInt32 = 9
MAPI_E_TOO_MANY_RECIPIENTS: UInt32 = 10
MAPI_E_ATTACHMENT_NOT_FOUND: UInt32 = 11
MAPI_E_ATTACHMENT_OPEN_FAILURE: UInt32 = 12
MAPI_E_ATTACHMENT_WRITE_FAILURE: UInt32 = 13
MAPI_E_UNKNOWN_RECIPIENT: UInt32 = 14
MAPI_E_BAD_RECIPTYPE: UInt32 = 15
MAPI_E_NO_MESSAGES: UInt32 = 16
MAPI_E_INVALID_MESSAGE: UInt32 = 17
MAPI_E_TEXT_TOO_LARGE: UInt32 = 18
MAPI_E_INVALID_SESSION: UInt32 = 19
MAPI_E_TYPE_NOT_SUPPORTED: UInt32 = 20
MAPI_E_AMBIGUOUS_RECIPIENT: UInt32 = 21
MAPI_E_AMBIG_RECIP: UInt32 = 21
MAPI_E_MESSAGE_IN_USE: UInt32 = 22
MAPI_E_NETWORK_FAILURE: UInt32 = 23
MAPI_E_INVALID_EDITFIELDS: UInt32 = 24
MAPI_E_INVALID_RECIPS: UInt32 = 25
MAPI_E_NOT_SUPPORTED: UInt32 = 26
MAPI_E_UNICODE_NOT_SUPPORTED: UInt32 = 27
MAPI_E_ATTACHMENT_TOO_LARGE: UInt32 = 28
@winfunctype('MAPI32.dll')
def MAPIFreeBuffer(pv: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def LPMAPIADDRESS(lhSession: UIntPtr, ulUIParam: UIntPtr, lpszCaption: win32more.Windows.Win32.Foundation.PSTR, nEditFields: UInt32, lpszLabels: win32more.Windows.Win32.Foundation.PSTR, nRecips: UInt32, lpRecips: POINTER(win32more.Windows.Win32.System.Mapi.MapiRecipDesc), flFlags: UInt32, ulReserved: UInt32, lpnNewRecips: POINTER(UInt32), lppNewRecips: POINTER(POINTER(win32more.Windows.Win32.System.Mapi.MapiRecipDesc))) -> UInt32: ...
@winfunctype_pointer
def LPMAPIDELETEMAIL(lhSession: UIntPtr, ulUIParam: UIntPtr, lpszMessageID: win32more.Windows.Win32.Foundation.PSTR, flFlags: UInt32, ulReserved: UInt32) -> UInt32: ...
@winfunctype_pointer
def LPMAPIDETAILS(lhSession: UIntPtr, ulUIParam: UIntPtr, lpRecip: POINTER(win32more.Windows.Win32.System.Mapi.MapiRecipDesc), flFlags: UInt32, ulReserved: UInt32) -> UInt32: ...
@winfunctype_pointer
def LPMAPIFINDNEXT(lhSession: UIntPtr, ulUIParam: UIntPtr, lpszMessageType: win32more.Windows.Win32.Foundation.PSTR, lpszSeedMessageID: win32more.Windows.Win32.Foundation.PSTR, flFlags: UInt32, ulReserved: UInt32, lpszMessageID: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype_pointer
def LPMAPIFREEBUFFER(pv: VoidPtr) -> UInt32: ...
@winfunctype_pointer
def LPMAPILOGOFF(lhSession: UIntPtr, ulUIParam: UIntPtr, flFlags: UInt32, ulReserved: UInt32) -> UInt32: ...
@winfunctype_pointer
def LPMAPILOGON(ulUIParam: UIntPtr, lpszProfileName: win32more.Windows.Win32.Foundation.PSTR, lpszPassword: win32more.Windows.Win32.Foundation.PSTR, flFlags: UInt32, ulReserved: UInt32, lplhSession: POINTER(UIntPtr)) -> UInt32: ...
@winfunctype_pointer
def LPMAPIREADMAIL(lhSession: UIntPtr, ulUIParam: UIntPtr, lpszMessageID: win32more.Windows.Win32.Foundation.PSTR, flFlags: UInt32, ulReserved: UInt32, lppMessage: POINTER(POINTER(win32more.Windows.Win32.System.Mapi.MapiMessage))) -> UInt32: ...
@winfunctype_pointer
def LPMAPIRESOLVENAME(lhSession: UIntPtr, ulUIParam: UIntPtr, lpszName: win32more.Windows.Win32.Foundation.PSTR, flFlags: UInt32, ulReserved: UInt32, lppRecip: POINTER(POINTER(win32more.Windows.Win32.System.Mapi.MapiRecipDesc))) -> UInt32: ...
@winfunctype_pointer
def LPMAPISAVEMAIL(lhSession: UIntPtr, ulUIParam: UIntPtr, lpMessage: POINTER(win32more.Windows.Win32.System.Mapi.MapiMessage), flFlags: UInt32, ulReserved: UInt32, lpszMessageID: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype_pointer
def LPMAPISENDDOCUMENTS(ulUIParam: UIntPtr, lpszDelimChar: win32more.Windows.Win32.Foundation.PSTR, lpszFilePaths: win32more.Windows.Win32.Foundation.PSTR, lpszFileNames: win32more.Windows.Win32.Foundation.PSTR, ulReserved: UInt32) -> UInt32: ...
@winfunctype_pointer
def LPMAPISENDMAILW(lhSession: UIntPtr, ulUIParam: UIntPtr, lpMessage: POINTER(win32more.Windows.Win32.System.Mapi.MapiMessageW), flFlags: UInt32, ulReserved: UInt32) -> UInt32: ...
LPMAPISENDMAIL = UnicodeAlias('LPMAPISENDMAILW')
class MapiFileDescW(Structure):
    ulReserved: UInt32
    flFlags: UInt32
    nPosition: UInt32
    lpszPathName: win32more.Windows.Win32.Foundation.PWSTR
    lpszFileName: win32more.Windows.Win32.Foundation.PWSTR
    lpFileType: VoidPtr
MapiFileDesc = UnicodeAlias('MapiFileDescW')
class MapiFileTagExt(Structure):
    ulReserved: UInt32
    cbTag: UInt32
    lpTag: POINTER(Byte)
    cbEncoding: UInt32
    lpEncoding: POINTER(Byte)
class MapiMessageW(Structure):
    ulReserved: UInt32
    lpszSubject: win32more.Windows.Win32.Foundation.PWSTR
    lpszNoteText: win32more.Windows.Win32.Foundation.PWSTR
    lpszMessageType: win32more.Windows.Win32.Foundation.PWSTR
    lpszDateReceived: win32more.Windows.Win32.Foundation.PWSTR
    lpszConversationID: win32more.Windows.Win32.Foundation.PWSTR
    flFlags: UInt32
    lpOriginator: POINTER(win32more.Windows.Win32.System.Mapi.MapiRecipDescW)
    nRecipCount: UInt32
    lpRecips: POINTER(win32more.Windows.Win32.System.Mapi.MapiRecipDescW)
    nFileCount: UInt32
    lpFiles: POINTER(win32more.Windows.Win32.System.Mapi.MapiFileDescW)
MapiMessage = UnicodeAlias('MapiMessageW')
class MapiRecipDescW(Structure):
    ulReserved: UInt32
    ulRecipClass: UInt32
    lpszName: win32more.Windows.Win32.Foundation.PWSTR
    lpszAddress: win32more.Windows.Win32.Foundation.PWSTR
    ulEIDSize: UInt32
    lpEntryID: VoidPtr
MapiRecipDesc = UnicodeAlias('MapiRecipDescW')


make_ready(__name__)
